//************************************************
//*  OMR Interface DLL 32 Bits functions         *
//*  Library Version 2.0                         *
//*  Copyright 2009 - 2019 All rigths reserved   *
//*  RECOGNIFORM TECHNOLGIES SPA                 *
//*  www.recogniform.com - info@recogniform.com  *
//************************************************

unit recoomrapi;

interface

	function OMR_Init(Company,LicenseKey:PAnsiChar):Integer; stdcall;
	function OMR_Recognize(SessionHandle, DIBHandle, Left, Top, Right, Bottom:Integer):Integer; stdcall;
	function OMR_GetMarkDensityPercent(SessionHandle:Integer; Var Value:Double):Integer; stdcall;
	function OMR_GetMarkSizePercent(SessionHandle:Integer; Var Value:Double):Integer; stdcall;
	procedure OMR_Done(SessionHandle:Integer); stdcall;
	function OMR_ImportDDB(SessionHandle:Integer;BitmapHandle:Integer;PaletteHandle:Integer):Integer;  stdcall;
	function OMR_LoadImage(SessionHandle:Integer;FileName:PAnsiChar):Integer;  stdcall;
	procedure OMR_FreeImage(SessionHandle:Integer;DIBHandle:Integer);  stdcall;
	function OMR_RecognizeSignature(SessionHandle:Integer;DIBHandle:Integer;SignatureLeft, SignatureTop, SignatureRight, SignatureBottom, SignatureStrokeLengthPixel, SignatureStrokeAreaPixel, SignaturePrePrintedCharactersCount, SignaturePrePrintedLinePixel , SingatureNoisePixel:PInteger):Integer; stdcall;

implementation

	//  Goal: initialize the engine
	//  Requires: company name, license string
	//  Result: session handle
	function OMR_Init(Company,LicenseKey:PAnsiChar):Integer; stdcall; external 'RECOOMR.DLL';

	//  Goal: recognize a check box
	//  Requires: session handle, dib handle, mark coordinates
	//  Result: success or error
	function OMR_Recognize(SessionHandle, DIBHandle, Left, Top, Right, Bottom:Integer):Integer; stdcall; external 'RECOOMR.DLL';

	//  Goal: retrieve the percentage of ink
	//  Requires: session handle
	//  Result: success or error, the percentage of black pixels
	function OMR_GetMarkDensityPercent(SessionHandle:Integer; Var Value:Double):Integer; stdcall; external 'RECOOMR.DLL';

	//  Goal: the size of mark in percentage respect to the box diagonal size
	//  Requires: session handle
	//  Result: success or error, the size of mark in percentage
	function OMR_GetMarkSizePercent(SessionHandle:Integer; Var Value:Double):Integer; stdcall; external 'RECOOMR.DLL';

	//  Goal: deinitialize the engine
	//  Requires: session handle
	//  Result: n/a
	procedure OMR_Done(SessionHandle:Integer); stdcall; external 'RECOOMR.DLL';

	//  Goal: import a DDB building an DIB handle.
	//  Requires: session handle, PaletteHandle
	//  Result: BitmapHandle
	function OMR_ImportDDB(SessionHandle:Integer;BitmapHandle:Integer;PaletteHandle:Integer):Integer;  stdcall; external 'RECOOMR.DLL';

	//  Goal: load an image from file getting a DIB handle
	//  Requires: session handle, file name
	//  Result: the dib handle
	function OMR_LoadImage(SessionHandle:Integer;FileName:PAnsiChar):Integer;  stdcall; external 'RECOOMR.DLL';

	//  Goal: free from memory an image previously loaded
	//  Requires: session handle, DIB handle
	//  Result: n/a
	procedure OMR_FreeImage(SessionHandle:Integer;DIBHandle:Integer);  stdcall; external 'RECOOMR.DLL';

	//  Goal: recognize if there is a signature on a part of document
	//  Requires: session handle, DIB handle
	//  Result: success or error, signature coordinates, stroke length, signature pixel of located printed character, number of the pixel of recognized horizontal line, noise in pixel
	function OMR_RecognizeSignature(SessionHandle:Integer;DIBHandle:Integer;SignatureLeft, SignatureTop, SignatureRight, SignatureBottom, SignatureStrokeLengthPixel, SignatureStrokeAreaPixel, SignaturePrePrintedCharactersCount, SignaturePrePrintedLinePixel , SingatureNoisePixel:PInteger):Integer; stdcall; external 'RECOOMR.DLL';

end.
